@@ -137,7 +137,7 @@ INVALIDPARAMETER_CDNCLSTOPICNOTEXIST = 'InvalidParameter.CdnClsTopicNotExist'
 # 缓存配置不合法，请确认后重试。
 INVALIDPARAMETER_CDNCONFIGINVALIDCACHE = 'InvalidParameter.CdnConfigInvalidCache'
 
-# 域名不合法。
+# 域名不符合规范，请确认域名是否符合规范。
 INVALIDPARAMETER_CDNCONFIGINVALIDHOST = 'InvalidParameter.CdnConfigInvalidHost'
 
 # 标签配置不合法。
@@ -149,7 +149,7 @@ INVALIDPARAMETER_CDNCONFIGTAGREQUIRED = 'InvalidParameter.CdnConfigTagRequired'
 # 域名拥有特殊配置，需人工处理。
 INVALIDPARAMETER_CDNHOSTHASSPECIALCONFIG = 'InvalidParameter.CdnHostHasSpecialConfig'
 
-# 该域名为内部域名，不可接入。
+# 该域名属于指定账号域名，不允许接入。
 INVALIDPARAMETER_CDNHOSTINTERNALHOST = 'InvalidParameter.CdnHostInternalHost'
 
 # 错误的中间源配置。
@@ -179,6 +179,9 @@ INVALIDPARAMETER_CDNINVALIDPARAMMETRIC = 'InvalidParameter.CdnInvalidParamMetric
 # ServiceType字段不合法，请确认后重试。
 INVALIDPARAMETER_CDNINVALIDPARAMSERVICETYPE = 'InvalidParameter.CdnInvalidParamServiceType'
 
+# 配置暂不支持开启该配置。
+INVALIDPARAMETER_CDNKEYRULESEXCLUDECUSTOMREQUIRESFULLLEGO = 'InvalidParameter.CdnKeyRulesExcludeCustomRequiresFullLego'
+
 # QueryString字段不合法，请确认后重试。
 INVALIDPARAMETER_CDNKEYRULESINVALIDQUERYSTRINGVALUE = 'InvalidParameter.CdnKeyRulesInvalidQueryStringValue'
 
@@ -290,6 +293,9 @@ LIMITEXCEEDED_CAMTAGKEYTOOLONG = 'LimitExceeded.CamTagKeyTooLong'
 # 单个标签键对应标签值不能超过1000。
 LIMITEXCEEDED_CAMTAGKEYTOOMANYTAGVALUE = 'LimitExceeded.CamTagKeyTooManyTagValue'
 
+# 域名绑定标签数量超出限制。
+LIMITEXCEEDED_CAMTAGQUOTAEXCEEDLIMIT = 'LimitExceeded.CamTagQuotaExceedLimit'
+
 # 单个用户最多1000个不同的key。
 LIMITEXCEEDED_CAMUSERTOOMANYTAGKEY = 'LimitExceeded.CamUserTooManyTagKey'
 
@@ -326,7 +332,7 @@ LIMITEXCEEDED_CDNPUSHEXCEEDDAYLIMIT = 'LimitExceeded.CdnPushExceedDayLimit'
 # 批量查询IP归属个数超过限制。
 LIMITEXCEEDED_CDNQUERYIPBATCHTOOMANY = 'LimitExceeded.CdnQueryIpBatchTooMany'
 
-# 接入域名数超出限制。
+# 用户域名数量已达上限，请联系腾讯云工程师处理。
 LIMITEXCEEDED_CDNUSERTOOMANYHOSTS = 'LimitExceeded.CdnUserTooManyHosts'
 
 # 日志大小超限。
@@ -368,7 +374,7 @@ RESOURCENOTFOUND = 'ResourceNotFound'
 # 标签键不存在。
 RESOURCENOTFOUND_CAMTAGKEYNOTEXIST = 'ResourceNotFound.CamTagKeyNotExist'
 
-# 账号下无此域名，请确认后重试。
+# 未查询到该域名，请确认域名是否正确。
 RESOURCENOTFOUND_CDNHOSTNOTEXISTS = 'ResourceNotFound.CdnHostNotExists'
 
 # 项目不存在，请确认后重试。
@@ -377,7 +383,7 @@ RESOURCENOTFOUND_CDNPROJECTNOTEXISTS = 'ResourceNotFound.CdnProjectNotExists'
 # 未开通CDN服务，请开通后使用此接口。
 RESOURCENOTFOUND_CDNUSERNOTEXISTS = 'ResourceNotFound.CdnUserNotExists'
 
-# 接入域名数超出限制。
+# 用户域名数量已达上限，请联系腾讯云工程师处理。
 RESOURCENOTFOUND_CDNUSERTOOMANYHOSTS = 'ResourceNotFound.CdnUserTooManyHosts'
 
 # 索引不存在。
@@ -410,7 +416,7 @@ RESOURCEUNAVAILABLE_CDNHOSTEXISTSINTCB = 'ResourceUnavailable.CdnHostExistsInTcb
 # 域名被锁定。
 RESOURCEUNAVAILABLE_CDNHOSTISLOCKED = 'ResourceUnavailable.CdnHostIsLocked'
 
-# 域名不安全或为恶意域名，不可接入。
+# 该域名有违法违规风险，不可接入。
 RESOURCEUNAVAILABLE_CDNHOSTISMALICIOUS = 'ResourceUnavailable.CdnHostIsMalicious'
 
 # 域名未下线。
@@ -419,9 +425,12 @@ RESOURCEUNAVAILABLE_CDNHOSTISNOTOFFLINE = 'ResourceUnavailable.CdnHostIsNotOffli
 # 域名已下线，无法提交预热。
 RESOURCEUNAVAILABLE_CDNHOSTISNOTONLINE = 'ResourceUnavailable.CdnHostIsNotOnline'
 
-# 域名未备案。
+# 域名未备案，请将域名备案。备案同步周期为2小时，若域名已备案，可稍后重新接入。
 RESOURCEUNAVAILABLE_CDNHOSTNOICP = 'ResourceUnavailable.CdnHostNoIcp'
 
+# 该域名已在云点播内接入，请先在云点播内删除域名后再接入。
+RESOURCEUNAVAILABLE_HOSTEXISTINVOD = 'ResourceUnavailable.HostExistInVod'
+
 # SCDN服务未生效，请购买或续费SCDN套餐后重试。
 RESOURCEUNAVAILABLE_SCDNUSERNOPACKAGE = 'ResourceUnavailable.ScdnUserNoPackage'
 
@@ -446,7 +455,7 @@ UNAUTHORIZEDOPERATION_CDNDOMAINRECORDNOTVERIFIED = 'UnauthorizedOperation.CdnDom
 # 域名在内部系统已存在，请提工单处理。
 UNAUTHORIZEDOPERATION_CDNHOSTEXISTSININTERNAL = 'UnauthorizedOperation.CdnHostExistsInInternal'
 
-# 域名现存在风险，不可接入。
+# 该域名涉及违法违规风险，不可接入。
 UNAUTHORIZEDOPERATION_CDNHOSTINICPBLACKLIST = 'UnauthorizedOperation.CdnHostInIcpBlacklist'
 
 # 该域名属于其他账号，您没有权限接入。
@@ -506,6 +515,9 @@ UNAUTHORIZEDOPERATION_CSRFERROR = 'UnauthorizedOperation.CsrfError'
 # 鉴权域名为空。
 UNAUTHORIZEDOPERATION_DOMAINEMPTY = 'UnauthorizedOperation.DomainEmpty'
 
+# 请前往CDN控制台进行操作。
+UNAUTHORIZEDOPERATION_ECDNMIGRATEDCDN = 'UnauthorizedOperation.EcdnMigratedCdn'
+
 # 未授权的操作。
 UNAUTHORIZEDOPERATION_NOPERMISSION = 'UnauthorizedOperation.NoPermission'
 
